@@ -1,7 +1,7 @@
 mod image;
 mod pixel;
 pub use crate::image::Image;
-pub use crate::pixel::{Pixel, Gray, Rgb};
+pub use crate::pixel::{Gray, Pixel, Rgb};
 
 #[cfg(test)]
 mod tests {
